@@ -8,7 +8,10 @@ from numpy import log10
 
 Mw=18.0160 # molecular weight of water
 Md=28.9660 # molecular weight of dry air
-
+R =  8.31432E3 # gas constant
+Rd = R/Md # specific gas constant for dry air
+Rv = R/Mw # specific gas constant for vapour
+eps = Mw/Md
 #saturation pressure
 def esat(T):
     ''' get sateration pressure (units [Pa]) for a given air temperature (units [K])'''
@@ -42,3 +45,15 @@ def mixr2ea(P,mixr):
     '''
     return P*mixr/(0.622+ea)
 
+# not tested
+def ah2mixr (rhov,p,T)
+    '''conversion from absolute humidity (units [kg/m**3]) to mixing ratio (units also [kg/kg])
+    '''
+    return (Rd * T)/(p/rhov-Rv*T)
+
+# not tested
+def wvap2sh(e,p):
+    '''conversion from water vapour pressure (units [Pa]) to specific humidity (units [kg/kg]) 
+    '''
+    return eps*e/(p-(1.-eps)*e)
+
